
@echo OFF
cls
COLOR 0A

rem <PROGRAM-HEADER>
echo **************************************************
echo *                                                *
echo * Windows language 4                             *
echo *                                                *
echo **************************************************
echo.
echo Description:
echo        Display Windows language.
echo.
echo --------------------------------------------------------------------------------
rem: Informations :
rem         Author   : Vincent Duvernet
rem         Company  : Nolm Informatique
rem         Web site : http://www.nolme.com
rem 
rem: Version :
rem         Creation Date     : 2015/10/07
rem         Last modification : 2015/10/07
rem         Script version    : 1.0
rem 
rem: History :
rem         1.0 (2015-10-07) : First version
rem 
rem: Bug report :
rem         None.
rem 
rem: Pre-required application(s) :
rem         Microsoft .NET framework 4.0
rem         Nolm Informatique Command Line Tools 4.x
rem 
rem: Windows compatibility :
rem         Workstations : XP SP3, Vista SP2, 7 SP1, 8, 10
rem         Server       : 2003 SP3, 2008 SP2, 2008 R2 SP2, 2012, 2012 R2
rem 
rem: Details of languages :
rem         Language Name         Language ID
rem         English (default)     0409
rem         French                040c
rem         Spanish               0c0a
rem         Italian               0410
rem         Swedish               041D
rem         Dutch                 0413
rem         Brazilian             0416
rem         Finnish               040b
rem         Norwegian             0414
rem         Danish                0406
rem         Hungarian             040e
rem         Polish                0415
rem         Russian               0419
rem         Czech                 0405
rem         Greek                 0408
rem         Portuguese            0816
rem         Turkish               041f
rem         Japanese              0411
rem         Korean                0412
rem         German                0407
rem         Chinese (Simplified)  0804
rem         Chinese (Traditional) 0404
rem         Arabic                0401
rem         Hebrew                040d
rem 
rem: Variables :
rem         Name                            Type       Visibility     Values / Comment
rem         ----------------------------------------------------------------------------------------------------------------
rem         g_strBatchPath                  String     Static         Current script directory.
rem         g_strCurrentDirectory           String     Static         Current directory when running this script.
rem         g_strCmdLineToolsFolder         String     Static         CmdLineTools binary folder. Change this variable to use other version of CmdLineTools.
rem         g_strInternalOutputFullFilename String     Static         Output filename for data exchange between application and script.
rem         g_strCommand%%NAME%%FullPath    String     Static         Full filename of CmdLineTools application. Replace %%NAME%% by AppVersion4, Is64Bits4...
rem 
rem         g_strRootPath                   String     Internal       
rem         g_strPath                       String     Internal       
rem         g_strKey                        String     Internal       
rem         g_strLanguageCode               String     Internal       
rem         g_strLanguage                   String     Internal       
rem         g_strLanguagePath               String     Internal       
rem 
rem: Sources :
rem         http://stackoverflow.com/questions/953416/find-out-the-language-windows-was-installed-as
rem         http://www.windowsitpro.com/article/configuration/where-in-the-registry-is-the-language-setting-for-each-user-stored-
rem         http://msdn.microsoft.com/en-us/library/ms533052(v=vs.85).aspx
rem 
rem: Notes :
rem         None.
rem 
rem ************************************************************************************************************************
rem </PROGRAM-HEADER>

rem <INIT>
echo [Initialisation]
echo ----------------
echo.
setlocal enabledelayedexpansion
set g_strBatchPath=%~dp0
set g_strCurrentDirectory=%CD%
set g_strCmdLineToolsFolder=!g_strBatchPath!\..\bin
set g_strInternalOutputFullFilename=%TEMP%\Nolme_SDK_Output.log
set g_strTempFolder=!g_strBatchPath!\..\temp

set g_strCommandRegRead4FullPath=!g_strCmdLineToolsFolder!\RegRead4.exe

set g_strRootPath=HKLM
set g_strPath=SYSTEM\CurrentControlSet\Control\Nls\Language
set g_strKey=InstallLanguage
set g_strLanguageCode=0409
set g_strLanguage=English
set g_strLanguagePath=en-US

rem Display current directory
echo - Batch directory : 
echo !g_strBatchPath!
echo.
rem Display current directory
echo - Current directory : 
echo !g_strCurrentDirectory!
echo.
rem Display CmdLineTools directory
echo - CmdLineTools directory : 
echo !g_strCmdLineToolsFolder!
echo.

echo Initialization done.
echo.
rem </INIT>

rem <MAIN>
echo [Main]
echo ------
echo.

rem ----------------------------------------
REM
rem Get Windows language
REM
rem ----------------------------------------
echo Read Windows language in Registry
"!g_strCommandRegRead4FullPath!" -r %g_strRootPath% -p "%g_strPath%" -v "%g_strKey%" -x86 > "%g_strInternalOutputFullFilename%"
set /p g_strLanguageCode= < "!g_strInternalOutputFullFilename!"

echo Check result
if "%g_strLanguageCode%"=="0409" (
    set g_strLanguage=English
    set g_strLanguagePath=en-US
) else if "%g_strLanguageCode%"=="040C" (
    set g_strLanguage=French
    set g_strLanguagePath=fr-FR
) else if "%g_strLanguageCode%"=="0c0a" (
    set g_strLanguage=Spanish
    set g_strLanguagePath=es-ES
) else if "%g_strLanguageCode%"=="0410" (
    set g_strLanguage=Italian
    set g_strLanguagePath=it-IT
) else if "%g_strLanguageCode%"=="041D" (
    set g_strLanguage=Swedish
    set g_strLanguagePath=sv-SE
) else if "%g_strLanguageCode%"=="0413" (
    set g_strLanguage=Dutch
    set g_strLanguagePath=nl-BE
) else if "%g_strLanguageCode%"=="0416" (
    set g_strLanguage=Brazilian
    set g_strLanguagePath=pt-BR
) else if "%g_strLanguageCode%"=="040b" (
    set g_strLanguage=Finnish
    set g_strLanguagePath=fi-FI
) else if "%g_strLanguageCode%"=="0414" (
    set g_strLanguage=Norwegian
    set g_strLanguagePath=no
) else if "%g_strLanguageCode%"=="0406" (
    set g_strLanguage=Danish
    set g_strLanguagePath=da
) else if "%g_strLanguageCode%"=="040e" (
    set g_strLanguage=Hungarian
    set g_strLanguagePath=hu
) else if "%g_strLanguageCode%"=="0415" (
    set g_strLanguage=Polish
    set g_strLanguagePath=pl
) else if "%g_strLanguageCode%"=="0419" (
    set g_strLanguage=Russian
    set g_strLanguagePath=ru-RU
) else if "%g_strLanguageCode%"=="0405" (
    set g_strLanguage=Czech
    set g_strLanguagePath=cs
) else if "%g_strLanguageCode%"=="0408" (
    set g_strLanguage=Greek
    set g_strLanguagePath=el
) else if "%g_strLanguageCode%"=="0816" (
    set g_strLanguage=Portuguese
    set g_strLanguagePath=pt
) else if "%g_strLanguageCode%"=="041f" (
    set g_strLanguage=Turkish
    set g_strLanguagePath=tr
) else if "%g_strLanguageCode%"=="0411" (
    set g_strLanguage=Japanese
    set g_strLanguagePath=jp-JP
) else if "%g_strLanguageCode%"=="0412" (
    set g_strLanguage=Korean
    set g_strLanguagePath=ko
) else if "%g_strLanguageCode%"=="0407" (
    set g_strLanguage=German
    set g_strLanguagePath=de-DE
) else if "%g_strLanguageCode%"=="0804" (
    set g_strLanguage=Chinese - Simplified
    set g_strLanguagePath=zn-cn
) else if "%g_strLanguageCode%"=="0404" (
    set g_strLanguage=Chinese - Traditional
    set g_strLanguagePath=zh-hk
) else if "%g_strLanguageCode%"=="0401" (
    set g_strLanguage=Arabic
    set g_strLanguagePath=ar-sa
) else if "%g_strLanguageCode%"=="040d" (
    set g_strLanguage=Hebrew
    set g_strLanguagePath=he
) else (
    set g_strLanguage=Unknown
    set g_strLanguagePath=Unknown
)

echo Language : %g_strLanguage%
echo Code     : %g_strLanguageCode%
echo Path     : %g_strLanguagePath%
echo.
rem </MAIN>

rem <FOOTER>
echo.
echo [End of script]
echo ---------------
Pause
GOTO:EOF
rem </FOOTER>
rem ------------------------------------------------------------------------------------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------
rem --------------------------------------------         END OF FILE          ----------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------