
@echo OFF
cls
COLOR 0A

rem <PROGRAM-HEADER>
echo **************************************************
echo *                                                *
echo * UninstallApp 4                                 *
echo *                                                *
echo **************************************************
echo.
echo Description:
echo        Download, install and uninstall application.
echo.
echo --------------------------------------------------------------------------------
rem: Informations :
rem         Author   : Vincent Duvernet
rem         Company  : Nolm Informatique
rem         Web site : http://www.nolme.com
rem 
rem: Version :
rem         Creation Date     : 2015/10/07
rem         Last modification : 2015/10/07
rem         Script version    : 1.0
rem 
rem: History :
rem         1.0 (2015-10-07) : First version
rem 
rem: Bug report :
rem         None.
rem 
rem: Pre-required application(s) :
rem         Microsoft .NET framework 4.0
rem         Nolm Informatique Command Line Tools 4.x
rem 
rem: Windows compatibility :
rem         Workstations : XP SP3, Vista SP2, 7 SP1, 8, 10
rem         Server       : 2003 SP3, 2008 SP2, 2008 R2 SP2, 2012, 2012 R2
rem 
rem: Sources :
rem         None.
rem 
rem: Variables :
rem         Name                            Type       Visibility     Values / Comment
rem         ----------------------------------------------------------------------------------------------------------------
rem         g_strBatchPath                  String     Static         Current script directory.
rem         g_strCurrentDirectory           String     Static         Current directory when running this script.
rem         g_strCmdLineToolsFolder         String     Static         CmdLineTools binary folder. Change this variable to use other version of CmdLineTools.
rem         g_strInternalOutputFullFilename String     Static         Output filename for data exchange between application and script.
rem         g_strCommand%%NAME%%FullPath    String     Static         Full filename of CmdLineTools application. Replace %%NAME%% by AppVersion4, Is64Bits4...
rem 
rem         g_b64BitsOS                     Boolean    Output         0=32 bits OS. 1=64 bits OS.
rem 
rem         g_strHttpSourceUrl              String     Static         HTTP URL without filename
rem         g_strHttpSourceFilenameXX       String     Static         Source filename to download from Internet (32 or 64 bits)
rem         g_strFilenameXXMd5              String     Static         Source filename hash code (32 or 64 bits)
rem         g_strDestinationPath            String     Static         Destination folder WITHOUT '\' at the end
rem         g_strApplicationFullPath        String     Static         Full GetSystemInfo filename path
rem
rem: Notes :
rem         None.

rem 
rem ************************************************************************************************************************
rem </PROGRAM-HEADER>

rem <INIT>
echo [Initialisation]
echo ----------------
echo.
setlocal enabledelayedexpansion
set g_strBatchPath=%~dp0
set g_strCurrentDirectory=%CD%
set g_strCmdLineToolsFolder=!g_strBatchPath!\..\bin
set g_strInternalOutputFullFilename=%TEMP%\Nolme_SDK_Output.log
set g_strTempFolder=!g_strBatchPath!\..\temp

set g_strCommandIs64Bits4FullPath=!g_strCmdLineToolsFolder!\Is64Bits4.exe
set g_strCommandWGet4FullPath=!g_strCmdLineToolsFolder!\WGet4.exe
set g_strCommandWait4FullPath=!g_strCmdLineToolsFolder!\Wait4.exe
set g_strCommandUninstallApp4FullPath=!g_strCmdLineToolsFolder!\UninstallApp4.exe

rem Display current directory
echo - Batch directory : 
echo !g_strBatchPath!
echo.
rem Display current directory
echo - Current directory : 
echo !g_strCurrentDirectory!
echo.
rem Display CmdLineTools directory
echo - CmdLineTools directory : 
echo !g_strCmdLineToolsFolder!
echo.

CALL :FunctionIs64Bits
echo.

echo Initialization done.
echo.
rem </INIT>

rem <MAIN>
echo [Main]
echo ------
echo.

rem x64 file manage
if %g_b64BitsOS%==1 (
    echo Download x64
    set g_strHttpSourceUrl=http://javadl.sun.com/webapps/download/AutoDL?BundleId=60338
    set g_strHttpSourceFilename=""
    set g_strDestinationPath=%TEMP%
    set g_strDestinationFilename=jre-6u31-windows-x64.exe
    set g_strFilenameMd5Hash=166213BAF6D88CD3075601F890B8B462
    set g_strApplicationGUID={26A24AE4-039D-4CA4-87B4-2F86416031FF}
    set g_strInstallArgs=/s
    CALL :FunctionDownloadFile

    echo Run setup x64
    set g_strApplicationFullPath=!g_strDestinationPath!\!g_strDestinationFilename!
    "!g_strApplicationFullPath!" !g_strInstallArgs!
    echo Done.
    echo.
    
    echo Wait a bit for file lock release
    "!g_strCommandWait4FullPath!" -t 2
    echo Done.
    echo.
    
    echo Uninstall application
    rem Add Pause to let user check program install
    Pause
    set g_strUnInstallArgs=/quiet
    "!g_strCommandUninstallApp4FullPath!" -guid "!g_strApplicationGUID!" -args !g_strUnInstallArgs! -x64
    echo Done.
    echo.
)

rem Download file x86
echo Download x86
set g_strHttpSourceUrl=http://javadl.sun.com/webapps/download/AutoDL?BundleId=61044
set g_strHttpSourceFilename=""
set g_strDestinationPath=%TEMP%
set g_strDestinationFilename=jre-6u31-windows-i586.exe
set g_strFilenameMd5Hash=47D38E3362D874A338BD3B9D96765308
set g_strApplicationGUID={26A24AE4-039D-4CA4-87B4-2F83216031FF}
set g_strInstallArgs=/s
CALL :FunctionDownloadFile

echo Run setup x86
set g_strApplicationFullPath=!g_strDestinationPath!\!g_strDestinationFilename!
"!g_strApplicationFullPath!" !g_strInstallArgs!
echo Done.
echo.

echo Wait a bit for file lock release
"!g_strCommandWait4FullPath!" -t 2
echo Done.
echo.

echo Uninstall application
rem Add Pause to let user check program install
Pause
set g_strUnInstallArgs=/quiet
"!g_strCommandUninstallApp4FullPath!" -guid "!g_strApplicationGUID!" -args !g_strUnInstallArgs! -x86
echo Done.
echo.
rem </MAIN>

rem <FOOTER>
echo.
echo [End of script]
echo ---------------
Pause
GOTO:EOF
rem </FOOTER>

rem <LIBRARY>
rem ************************************************************************************************************************
rem 
rem FunctionIs64Bits ()
rem 
rem ************************************************************************************************************************
rem 
rem: Description :
rem         Initialize variable for 32/64 bits Windows version.
rem 
rem: Informations :
rem         Version       : 1.0
rem         Last modified : 2015-10-07
rem 
rem: Variables :
rem         Name                            Type       Visibility     Values / Comment
rem         ----------------------------------------------------------------------------------------------------------------
rem         g_strCommandIs64Bits4FullPath   String     Input          Full filename for application Is64Bits4.exe.
rem         g_b64BitsOS                     Boolean    Output         0=32 bits or error, 1=64 bits Windows version.
rem 
rem ************************************************************************************************************************
:FunctionIs64Bits
rem call command
"!g_strCommandIs64Bits4FullPath!" -q

rem check command result
if %ERRORLEVEL%==1 (
    set g_b64BitsOS=1
) else if %ERRORLEVEL%==0 (
    set g_b64BitsOS=0
) else (
    set g_b64BitsOS=0
    ECHO FunctionIs64Bits - Error getting 32/64 bits mode
)

rem display result
if %g_b64BitsOS%==1 (
    ECHO FunctionIs64Bits - This is a 64 bits Windows version
) else (
    ECHO FunctionIs64Bits - This is a 32 bits Windows version
)

:FunctionIs64Bits_End
GOTO:EOF

rem ************************************************************************************************************************
rem 
rem FunctionDownloadFile ()
rem 
rem ************************************************************************************************************************
rem 
rem: Description :
rem         Download a file from HTTP.
rem 
rem: Informations :
rem         Version       : 1.0
rem         Last modified : 2015-10-07
rem 
rem: Variables :
rem         Name                            Type       Visibility     Values / Comment
rem         ----------------------------------------------------------------------------------------------------------------
rem         g_strCommandWGet4FullPath       String     Input          Full filename for application WGet4.exe.
rem         g_strHttpSourceUrl              String     Input          Remote file HTTP url (without filename).
rem         g_strHttpSourceFilename         String     Input          Remote filename.
rem         g_strDestinationPath            String     Input          Local destination path.
rem         g_strFilenameMd5Hash            String     Input          MD5 hash to avoid downloading again.
rem         g_strDestinationFilename        String     Input          Destination filename.
rem 
rem ************************************************************************************************************************
:FunctionDownloadFile

echo Source filename : "!g_strHttpSourceFilename!" 
echo From: "%g_strHttpSourceUrl%" 
echo To: "!g_strDestinationPath!"
echo Destination filename : "!g_strDestinationFilename!" 

rem -f "!g_strHttpSourceFilename!"
"!g_strCommandWGet4FullPath!" -url "%g_strHttpSourceUrl%"  -d "!g_strDestinationPath!" -df "!g_strDestinationFilename!" -md5 "%g_strFilenameMd5Hash%"
if %ERRORLEVEL%==-1 (
    echo Help displayed - WE CAN'T REACH THIS CASE IN THIS SAMPLE
) else if %ERRORLEVEL%==1 (
    echo All is OK.
) else if %ERRORLEVEL%==0 (
    echo Value not found - WE CAN'T REACH THIS CASE IN THIS SAMPLE
) else (
    echo ERROR - Unknown value - WE CAN'T REACH THIS CASE IN THIS SAMPLE
)
:FunctionDownloadFile_End
GOTO:EOF

rem </LIBRARY>

rem ------------------------------------------------------------------------------------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------
rem --------------------------------------------         END OF FILE          ----------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------