
@echo OFF
cls
COLOR 0A

rem <PROGRAM-HEADER>
echo **************************************************
echo *                                                *
echo * CheckRange4                                    *
echo *                                                *
echo **************************************************
echo.
echo Description:
echo        Check range between value or IP.
echo.
echo --------------------------------------------------------------------------------
rem: Informations :
rem         Author   : Vincent Duvernet
rem         Company  : Nolm Informatique
rem         Web site : http://www.nolme.com
rem 
rem: Version :
rem         Creation Date     : 2015/10/07
rem         Last modification : 2015/10/07
rem         Script version    : 1.0
rem 
rem: History :
rem         1.0 (2015-10-07) : First version
rem 
rem: Bug report :
rem         None.
rem 
rem: Pre-required application(s) :
rem         Microsoft .NET framework 4.0
rem         Nolm Informatique Command Line Tools 4.x
rem 
rem: Windows compatibility :
rem         Workstations : XP SP3, Vista SP2, 7 SP1, 8, 10
rem         Server       : 2003 SP3, 2008 SP2, 2008 R2 SP2, 2012, 2012 R2
rem 
rem: Sources :
rem         None.
rem 
rem: Variables :
rem         Name                            Type       Visibility     Values / Comment
rem         ----------------------------------------------------------------------------------------------------------------
rem         g_strBatchPath                  String     Static         Current script directory.
rem         g_strCurrentDirectory           String     Static         Current directory when running this script.
rem         g_strCmdLineToolsFolder         String     Static         CmdLineTools binary folder. Change this variable to use other version of CmdLineTools.
rem         g_strInternalOutputFullFilename String     Static         Output filename for data exchange between application and script.
rem         g_strCommand%%NAME%%FullPath    String     Static         Full filename of CmdLineTools application. Replace %%NAME%% by AppVersion4, Is64Bits4...
rem 
rem: Notes :
rem         None.
rem 
rem ************************************************************************************************************************
rem </PROGRAM-HEADER>

rem <INIT>
echo [Initialisation]
echo ----------------
echo.
setlocal enabledelayedexpansion
set g_strBatchPath=%~dp0
set g_strCurrentDirectory=%CD%
set g_strCmdLineToolsFolder=!g_strBatchPath!\..\bin
set g_strInternalOutputFullFilename=%TEMP%\Nolme_SDK_Output.log

set g_strCommandCheckRange4FullPath=!g_strCmdLineToolsFolder!\CheckRange4.exe

echo Initialization done.
echo.
rem </INIT>

rem <MAIN>
echo [Main]
echo ------
echo.

echo Version 1 (number) :
echo --------------------
echo Check number range (1/2) 23 in [-100..100]
"!g_strCommandCheckRange4FullPath!" -n -100 100 23
echo.

echo Check number range (2/2) 110 in  [-100..100]
"!g_strCommandCheckRange4FullPath!" -n -100 100 110
echo.

echo Version 2 (IPv4) :
echo ------------------
echo Check IP range (1/2) 192.168.100 in [192.168.0.1 - 192.168.0.254]
"!g_strCommandCheckRange4FullPath!" -ipv4 192.168.0.1 192.168.0.254 192.168.100
echo.

echo Check IP range (2/2) 127.0.0.1 in [192.168.0.1 - 192.168.0.254]
"!g_strCommandCheckRange4FullPath!" -ipv4 192.168.0.1 192.168.0.254 127.0.0.1
echo.


echo Version 3 - quiet mode (use %%ERRORLEVEL%% to display result) :
echo ---------------------------------------------------------------
echo Check number range (1/2) 23 in [-100..100]
"!g_strCommandCheckRange4FullPath!" -n -100 100 23 -q
if %ERRORLEVEL%==0 (
    echo Outside of range - WE CAN'T REACH THIS CASE IN THIS SAMPLE
) else if %ERRORLEVEL%==1 (
    echo Inside range. Ok.
) else (
    echo ERROR - WE CAN'T REACH THIS CASE IN THIS SAMPLE
)
echo.

echo Check number range (2/2) 110 in  [-100..100]
"!g_strCommandCheckRange4FullPath!" -n -100 100 110 -q
if %ERRORLEVEL%==0 (
    echo Outside of range. Ok.
) else if %ERRORLEVEL%==1 (
    echo Inside range - WE CAN'T REACH THIS CASE IN THIS SAMPLE
) else (
    echo ERROR - WE CAN'T REACH THIS CASE IN THIS SAMPLE
)
rem </MAIN>

rem <FOOTER>
echo.
echo [End of script]
echo ---------------
Pause
GOTO:EOF
rem </FOOTER>
rem ------------------------------------------------------------------------------------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------
rem --------------------------------------------         END OF FILE          ----------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------